==> haskell-opentelemetry-0.8.0-149.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-opentelemetry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 opentelemetry
version:              0.8.0
visibility:           public
id:                   opentelemetry-0.8.0-78VWkW9YLqi7UDSXGjjBFN
key:                  opentelemetry-0.8.0-78VWkW9YLqi7UDSXGjjBFN
license:              Apache-2.0
maintainer:           ethercrow@gmail.com
author:               Dmitry Ivanov
description:          The OpenTelemetry Haskell Client https://opentelemetry.io
category:             OpenTelemetry
abi:                  569fedcd22bab0ad8947d371f8e85dee
exposed:              True
exposed-modules:
    OpenTelemetry.Eventlog OpenTelemetry.Eventlog_Internal
    OpenTelemetry.Metrics_Internal OpenTelemetry.Propagation
    OpenTelemetry.SpanContext

import-dirs:          /usr/lib/ghc-9.6.6/site-local/opentelemetry-0.8.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/opentelemetry-0.8.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/opentelemetry-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-opentelemetry
hs-libraries:         HSopentelemetry-0.8.0-78VWkW9YLqi7UDSXGjjBFN
depends:
    base-4.18.2.1 bytestring-0.11.5.3 exceptions-0.10.7
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z

haddock-interfaces:
    /usr/share/doc/haskell-opentelemetry/html/opentelemetry.haddock

haddock-html:         /usr/share/doc/haskell-opentelemetry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-opentelemetry-0.8.0-150-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-opentelemetry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 opentelemetry
version:              0.8.0
visibility:           public
id:                   opentelemetry-0.8.0-Dm3Gp7158KP4xW3BJICjGm
key:                  opentelemetry-0.8.0-Dm3Gp7158KP4xW3BJICjGm
license:              Apache-2.0
maintainer:           ethercrow@gmail.com
author:               Dmitry Ivanov
description:          The OpenTelemetry Haskell Client https://opentelemetry.io
category:             OpenTelemetry
abi:                  63247cef285909293bb1a28850b938ed
exposed:              True
exposed-modules:
    OpenTelemetry.Eventlog OpenTelemetry.Eventlog_Internal
    OpenTelemetry.Metrics_Internal OpenTelemetry.Propagation
    OpenTelemetry.SpanContext

import-dirs:          /usr/lib/ghc-9.6.6/site-local/opentelemetry-0.8.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/opentelemetry-0.8.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/opentelemetry-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-opentelemetry
hs-libraries:         HSopentelemetry-0.8.0-Dm3Gp7158KP4xW3BJICjGm
depends:
    base-4.18.2.1 bytestring-0.11.5.3 exceptions-0.10.7
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD

haddock-interfaces:
    /usr/share/doc/haskell-opentelemetry/html/opentelemetry.haddock

haddock-html:         /usr/share/doc/haskell-opentelemetry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
